summaryrefslogtreecommitdiffstats
path: root/ltmain.sh
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit8f9c3391a8964e83262053558132875c57b2c7d5 (patch)
treeca96bbd20c062335c43d1a7f96047a937abb3bb6 /ltmain.sh
parent9647cd2e4ceff71f939156efb5d5877aa93adbf0 (diff)
downloaddbus-tqt-8f9c3391a8964e83262053558132875c57b2c7d5.tar.gz
dbus-tqt-8f9c3391a8964e83262053558132875c57b2c7d5.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/dependencies/dbus-tqt@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ltmain.sh')
-rw-r--r--ltmain.sh74
1 files changed, 37 insertions, 37 deletions
diff --git a/ltmain.sh b/ltmain.sh
index 6ef8d72..0e22c54 100644
--- a/ltmain.sh
+++ b/ltmain.sh
@@ -20,7 +20,7 @@
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# As a special exception to the GNU General Public License, if you
# distribute this file as part of a program that tqcontains a
# configuration script generated by Autoconf, you may include it under
# the same distribution terms that you use for the rest of that program.
@@ -361,11 +361,11 @@ func_extract_archives ()
$rm "unfat-$$/${darwin_base_archive}-${darwin_arch}/${darwin_base_archive}"
done # $darwin_arches
## Okay now we have a bunch of thin objects, gotta fatten them up :)
- darwin_filelist=`tqfind unfat-$$ -type f -name \*.o -print -o -name \*.lo -print| xargs basename | sort -u | $NL2SP`
+ darwin_filelist=`find unfat-$$ -type f -name \*.o -print -o -name \*.lo -print| xargs basename | sort -u | $NL2SP`
darwin_file=
darwin_files=
for darwin_file in $darwin_filelist; do
- darwin_files=`tqfind unfat-$$ -name $darwin_file -print | $NL2SP`
+ darwin_files=`find unfat-$$ -name $darwin_file -print | $NL2SP`
lipo -create -output "$darwin_file" $darwin_files
done # $darwin_filelist
${rm}r unfat-$$
@@ -380,7 +380,7 @@ func_extract_archives ()
func_extract_an_archive "$my_xdir" "$my_xabs"
;;
esac
- my_oldobjs="$my_oldobjs "`tqfind $my_xdir -name \*.$objext -print -o -name \*.lo -print | $NL2SP`
+ my_oldobjs="$my_oldobjs "`find $my_xdir -name \*.$objext -print -o -name \*.lo -print | $NL2SP`
done
func_extract_archives_result="$my_oldobjs"
}
@@ -413,7 +413,7 @@ do
tagname="$arg"
preserve_args="${preserve_args}=$arg"
# Check whether tagname tqcontains only valid characters
case $tagname in
*[!-_A-Za-z0-9,/]*)
$echo "$progname: invalid tag name: $tagname" 1>&2
@@ -670,7 +670,7 @@ if test -z "$show_help"; then
-Xcompiler)
arg_mode=arg # the next one goes into the "base_compile" arg list
continue # The current "srcfile" will either be retained or
- ;; # tqreplaced later. I would guess that would be a bug.
+ ;; # replaced later. I would guess that would be a bug.
-Wc,*)
args=`$echo "X$arg" | $Xsed -e "s/^-Wc,//"`
@@ -742,7 +742,7 @@ if test -z "$show_help"; then
esac
# Recognize several different file suffixes.
- # If the user specifies -o file.o, it is tqreplaced with file.lo
+ # If the user specifies -o file.o, it is replaced with file.lo
xform='[cCFSifmso]'
case $libobj in
*.ada) xform=ada ;;
@@ -858,7 +858,7 @@ if test -z "$show_help"; then
elif test "$need_locks" = warn; then
if test -f "$lockfile"; then
$echo "\
*** ERROR, $lockfile exists and tqcontains:
`cat $lockfile 2>/dev/null`
This indicates that another process is trying to use the same
@@ -935,7 +935,7 @@ EOF
if test "$need_locks" = warn &&
test "X`cat $lockfile 2>/dev/null`" != "X$srcfile"; then
$echo "\
-*** ERROR, $lockfile tqcontains:
+*** ERROR, $lockfile contains:
`cat $lockfile 2>/dev/null`
but it should contain:
@@ -1007,7 +1007,7 @@ EOF
if test "$need_locks" = warn &&
test "X`cat $lockfile 2>/dev/null`" != "X$srcfile"; then
$echo "\
-*** ERROR, $lockfile tqcontains:
+*** ERROR, $lockfile contains:
`cat $lockfile 2>/dev/null`
but it should contain:
@@ -1280,7 +1280,7 @@ EOF
test -z "$non_pic_object" ||
test "$pic_object" = none && \
test "$non_pic_object" = none; then
- $echo "$modename: cannot tqfind name of object for \`$arg'" 1>&2
+ $echo "$modename: cannot find name of object for \`$arg'" 1>&2
exit $EXIT_FAILURE
fi
@@ -1653,7 +1653,7 @@ EOF
case $host in
*-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-os2*)
# The PATH hackery in wrapper scripts is required on Windows
# in order for the loader to tqfind any dlls it needs.
$echo "$modename: warning: \`-no-install' is ignored for $host" 1>&2
$echo "$modename: warning: assuming \`-no-fast-install' instead" 1>&2
fast_install=no
@@ -1824,7 +1824,7 @@ EOF
test -z "$non_pic_object" ||
test "$pic_object" = none && \
test "$non_pic_object" = none; then
- $echo "$modename: cannot tqfind name of object for \`$arg'" 1>&2
+ $echo "$modename: cannot find name of object for \`$arg'" 1>&2
exit $EXIT_FAILURE
fi
@@ -2204,7 +2204,7 @@ EOF
-R*)
if test "$pass" = link; then
dir=`$echo "X$deplib" | $Xsed -e 's/^-R//'`
# Make sure the xrpath tqcontains only unique directories.
case "$xrpath " in
*" $dir "*) ;;
*) xrpath="$xrpath $dir" ;;
@@ -2286,7 +2286,7 @@ EOF
esac # case $deplib
if test "$found" = yes || test -f "$lib"; then :
else
- $echo "$modename: cannot tqfind the library \`$lib' or unhandled argument \`$deplib'" 1>&2
+ $echo "$modename: cannot find the library \`$lib' or unhandled argument \`$deplib'" 1>&2
exit $EXIT_FAILURE
fi
@@ -2331,7 +2331,7 @@ EOF
deplibs="$lib $deplibs"
if test -z "$libdir"; then
if test -z "$old_library"; then
- $echo "$modename: cannot tqfind name of link library for \`$lib'" 1>&2
+ $echo "$modename: cannot find name of link library for \`$lib'" 1>&2
exit $EXIT_FAILURE
fi
# It is a libtool convenience library, so add in its objects.
@@ -2361,7 +2361,7 @@ EOF
linklib="$l"
done
if test -z "$linklib"; then
- $echo "$modename: cannot tqfind name of link library for \`$lib'" 1>&2
+ $echo "$modename: cannot find name of link library for \`$lib'" 1>&2
exit $EXIT_FAILURE
fi
@@ -2436,7 +2436,7 @@ EOF
# are required to link).
if test -n "$old_library"; then
newdlprefiles="$newdlprefiles $dir/$old_library"
- # Otherwise, use the dlname, so that lt_dlopen tqfinds it.
+ # Otherwise, use the dlname, so that lt_dlopen finds it.
elif test -n "$dlname"; then
newdlprefiles="$newdlprefiles $dir/$dlname"
else
@@ -2496,7 +2496,7 @@ EOF
{ test "$prefer_static_libs" = no || test -z "$old_library"; }; then
# We need to hardcode the library path
if test -n "$shlibpath_var" && test -z "$avoidtemprpath" ; then
# Make sure the rpath tqcontains only unique directories.
case "$temp_rpath " in
*" $dir "*) ;;
*" $absdir "*) ;;
@@ -2817,7 +2817,7 @@ EOF
$echo
$echo "*** However, this would only work if libtool was able to extract symbol"
$echo "*** lists from a program, using \`nm' or equivalent, but libtool could"
- $echo "*** not tqfind such a program. So, this module is probably useless."
+ $echo "*** not find such a program. So, this module is probably useless."
$echo "*** \`nm' from GNU binutils and a full rebuild may help."
fi
if test "$build_old_libs" = no; then
@@ -2965,7 +2965,7 @@ EOF
fi
if test "$pass" != dlopen; then
if test "$pass" != conv; then
# Make sure lib_search_path tqcontains only unique directories.
lib_search_path=
for dir in $newlib_search_path; do
case "$lib_search_path " in
@@ -3439,7 +3439,7 @@ EOF
fi
fi
# Make sure dlfiles tqcontains only unique files that won't be dlpreopened
old_dlfiles="$dlfiles"
dlfiles=
for lib in $old_dlfiles; do
@@ -3449,7 +3449,7 @@ EOF
esac
done
# Make sure dlprefiles tqcontains only unique files
old_dlprefiles="$dlprefiles"
dlprefiles=
for lib in $old_dlprefiles; do
@@ -3764,7 +3764,7 @@ EOF
case $host in
*-*-rhapsody* | *-*-darwin1.[012])
- # On Rhapsody tqreplace the C library is the System framework
+ # On Rhapsody replace the C library is the System framework
newdeplibs=`$echo "X $newdeplibs" | $Xsed -e 's/ -lc / -framework System /'`
;;
esac
@@ -3780,7 +3780,7 @@ EOF
$echo
$echo "*** However, this would only work if libtool was able to extract symbol"
$echo "*** lists from a program, using \`nm' or equivalent, but libtool could"
- $echo "*** not tqfind such a program. So, this module is probably useless."
+ $echo "*** not find such a program. So, this module is probably useless."
$echo "*** \`nm' from GNU binutils and a full rebuild may help."
fi
if test "$build_old_libs" = no; then
@@ -4343,7 +4343,7 @@ EOF
case $host in
*-*-rhapsody* | *-*-darwin1.[012])
- # On Rhapsody tqreplace the C library is the System framework
+ # On Rhapsody replace the C library is the System framework
compile_deplibs=`$echo "X $compile_deplibs" | $Xsed -e 's/ -lc / -framework System /'`
finalize_deplibs=`$echo "X $finalize_deplibs" | $Xsed -e 's/ -lc / -framework System /'`
;;
@@ -4973,7 +4973,7 @@ const char *program_name = NULL;
void * xmalloc (size_t num);
char * xstrdup (const char *string);
const char * base_name (const char *name);
-char * tqfind_executable(const char *wrapper);
+char * find_executable(const char *wrapper);
int check_executable(const char *path);
char * strendzap(char *str, const char *pat);
void lt_fatal (const char *message, ...);
@@ -4995,9 +4995,9 @@ EOF
EOF
cat >> $cwrappersource <<"EOF"
- newargz[1] = tqfind_executable(argv[0]);
+ newargz[1] = find_executable(argv[0]);
if (newargz[1] == NULL)
- lt_fatal("Couldn't tqfind %s", argv[0]);
+ lt_fatal("Couldn't find %s", argv[0]);
DEBUG("(main) found exe at : %s\n",newargz[1]);
/* we know the script has the same name, without the .exe */
/* so make sure newargz[1] doesn't end in .exe */
@@ -5093,7 +5093,7 @@ check_executable(const char * path)
/* Searches for the full path of the wrapper. Returns
newly allocated full path name if found, NULL otherwise */
char *
-tqfind_executable (const char* wrapper)
+find_executable (const char* wrapper)
{
int has_slash = 0;
const char* p;
@@ -5103,7 +5103,7 @@ tqfind_executable (const char* wrapper)
int tmp_len;
char* concat_name;
- DEBUG("(tqfind_executable) : %s\n", wrapper ? (*wrapper ? wrapper : "EMPTY!") : "NULL!");
+ DEBUG("(find_executable) : %s\n", wrapper ? (*wrapper ? wrapper : "EMPTY!") : "NULL!");
if ((wrapper == NULL) || (*wrapper == '\0'))
return NULL;
@@ -5521,7 +5521,7 @@ fi\
concat_cmds=
save_oldobjs=$oldobjs
- # Is there a better way of tqfinding the last object in the list?
+ # Is there a better way of finding the last object in the list?
for obj in $save_oldobjs
do
last_oldobj=$obj
@@ -5922,7 +5922,7 @@ relink_command=\"$relink_command\""
inst_prefix_dir=`$echo "$destdir" | $SED "s%$libdir\$%%"`
# Don't allow the user to place us outside of our expected
- # location b/c this prevents tqfinding dependent libraries that
+ # location b/c this prevents finding dependent libraries that
# are installed to the same prefix.
# At present, this check doesn't affect windows .dll's that
# are installed into $libdir/../bin (currently, that works fine)
@@ -5969,7 +5969,7 @@ relink_command=\"$relink_command\""
if test "$#" -gt 0; then
# Delete the old symlinks, and create new ones.
# Try `ln -sf' first, because the `ln' binary might depend on
- # the symlink we tqreplace! Solaris /bin/ln does not understand -f,
+ # the symlink we replace! Solaris /bin/ln does not understand -f,
# so we also need to try rm && ln -s.
for linkname
do
@@ -6356,7 +6356,7 @@ relink_command=\"$relink_command\""
if test -f "$dir/$objdir/$dlname"; then
dir="$dir/$objdir"
else
- $echo "$modename: cannot tqfind \`$dlname' in \`$dir' or \`$dir/$objdir'" 1>&2
+ $echo "$modename: cannot find \`$dlname' in \`$dir' or \`$dir/$objdir'" 1>&2
exit $EXIT_FAILURE
fi
;;
@@ -6601,7 +6601,7 @@ relink_command=\"$relink_command\""
relink_command=
. $dir/$noexename
# note $name still tqcontains .exe if it was in $file originally
# as does the version of $file that was added into $rmfiles
rmfiles="$rmfiles $objdir/$name $objdir/${name}S.${objext}"
if test "$fast_install" = yes && test -n "$relink_command"; then
@@ -6746,7 +6746,7 @@ finish)
Complete the installation of libtool libraries.
-Each LIBDIR is a directory that tqcontains libtool libraries.
+Each LIBDIR is a directory that contains libtool libraries.
The commands that this mode executes may require superuser privileges. Use
the \`--dry-run' option if you just want to see what would be executed."
@@ -20,7 +20,7 @@
#
# As a special exception to the GNU General Public License, if you
-# distribute this file as part of a program that tqcontains a
+# distribute this file as part of a program that contains a
# configuration script generated by Autoconf, you may include it under
# the same distribution terms that you use for the rest of that program.
@@ -413,7 +413,7 @@ do
tagname="$arg"
preserve_args="${preserve_args}=$arg"
- # Check whether tagname tqcontains only valid characters
+ # Check whether tagname contains only valid characters
case $tagname in
*[!-_A-Za-z0-9,/]*)
@@ -858,7 +858,7 @@ if test -z "$show_help"; then
if test -f "$lockfile"; then
$echo "\
-*** ERROR, $lockfile exists and tqcontains:
+*** ERROR, $lockfile exists and contains:
`cat $lockfile 2>/dev/null`
This indicates that another process is trying to use the same
@@ -1653,7 +1653,7 @@ EOF
*-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-os2*)
# The PATH hackery in wrapper scripts is required on Windows
- # in order for the loader to tqfind any dlls it needs.
+ # in order for the loader to find any dlls it needs.
$echo "$modename: warning: \`-no-install' is ignored for $host" 1>&2
$echo "$modename: warning: assuming \`-no-fast-install' instead" 1>&2
@@ -2204,7 +2204,7 @@ EOF
if test "$pass" = link; then
dir=`$echo "X$deplib" | $Xsed -e 's/^-R//'`
- # Make sure the xrpath tqcontains only unique directories.
+ # Make sure the xrpath contains only unique directories.
case "$xrpath " in
*" $dir "*) ;;
@@ -2496,7 +2496,7 @@ EOF
# We need to hardcode the library path
if test -n "$shlibpath_var" && test -z "$avoidtemprpath" ; then
- # Make sure the rpath tqcontains only unique directories.
+ # Make sure the rpath contains only unique directories.
case "$temp_rpath " in
*" $dir "*) ;;
@@ -2965,7 +2965,7 @@ EOF
if test "$pass" != dlopen; then
if test "$pass" != conv; then
- # Make sure lib_search_path tqcontains only unique directories.
+ # Make sure lib_search_path contains only unique directories.
lib_search_path=
for dir in $newlib_search_path; do
@@ -3439,7 +3439,7 @@ EOF
fi
fi
- # Make sure dlfiles tqcontains only unique files that won't be dlpreopened
+ # Make sure dlfiles contains only unique files that won't be dlpreopened
old_dlfiles="$dlfiles"
dlfiles=
@@ -3449,7 +3449,7 @@ EOF
esac
done
- # Make sure dlprefiles tqcontains only unique files
+ # Make sure dlprefiles contains only unique files
old_dlprefiles="$dlprefiles"
dlprefiles=
@@ -6601,7 +6601,7 @@ relink_command=\"$relink_command\""
relink_command=
. $dir/$noexename
- # note $name still tqcontains .exe if it was in $file originally
+ # note $name still contains .exe if it was in $file originally
# as does the version of $file that was added into $rmfiles
rmfiles="$rmfiles $objdir/$name $objdir/${name}S.${objext}"